FxScreen class final

Inheritance
Annotations

Constructors

FxScreen({required Widget screenBuilder(BuildContext context, EdgeInsets screenPadding), Widget screenBackgroundBuilder(BuildContext context, EdgeInsets screenPadding)?, Widget screenOverlayBuilder(BuildContext context)?, PreferredSizeWidget? appBar, Widget? drawer, Widget? bottomSheet, GlobalKey<ScaffoldState>? scaffoldKey, Widget? endDrawer, void onDrawerChanged(bool)?, void onEndDrawerChanged(bool)?, Widget? bottomNavigationBar, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, FloatingActionButtonAnimator? floatingActionButtonAnimator, SystemUiOverlayStyle uiOverlayStyle = const SystemUiOverlayStyle(systemNavigationBarIconBrightness: Brightness.light, statusBarIconBrightness: Brightness.light, statusBarColor: Color(0x00000000), systemNavigationBarColor: Color(0x00000000)), Color? scaffoldBackgroundColor, bool encapsulateScreen = true, bool encapsulateBackground = false, bool extendBodyBehindAppBar = false, bool extendBodyBehindNavBar = false, bool resizeToAvoidBottomInset = false, Key? key})
const

Properties

appBar PreferredSizeWidget?
final
bottomNavigationBar Widget?
final
bottomSheet Widget?
final
drawer Widget?
final
encapsulateBackground bool
final
encapsulateScreen bool
final
endDrawer Widget?
final
extendBodyBehindAppBar bool
final
extendBodyBehindNavBar bool
final
floatingActionButton Widget?
final
floatingActionButtonAnimator FloatingActionButtonAnimator?
final
floatingActionButtonLocation FloatingActionButtonLocation?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDrawerChanged → void Function(bool)?
final
onEndDrawerChanged → void Function(bool)?
final
resizeToAvoidBottomInset bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffoldBackgroundColor Color?
final
scaffoldKey GlobalKey<ScaffoldState>?
final
screenBackgroundBuilder Widget Function(BuildContext context, EdgeInsets screenPadding)?
final
screenBuilder Widget Function(BuildContext context, EdgeInsets screenPadding)
final
screenOverlayBuilder Widget Function(BuildContext context)?
final
uiOverlayStyle SystemUiOverlayStyle
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited