FxButton class
FxButton is a customizable button widget with a default friendly style.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FxButton
Constructors
- FxButton({String content = "", Widget? widgetContent, Size minimumSize = const Size(30.0, 30.0), Size maximumSize = const Size(double.maxFinite, 50), EdgeInsets margin = const EdgeInsets.symmetric(vertical: 1, horizontal: 26), EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 10.0, vertical: 10.0), Color? contentColor, Color? overlayColor, Color? backgroundColor, Color? borderColor, AlignmentGeometry alignment = Alignment.center, double borderRadius = 7.0, Color? disabledColor, bool isCompact = false, TextStyle? textStyle, required dynamic onPressedF()?, Key? key})
-
const
Properties
- alignment → AlignmentGeometry
-
The alignment of the button's content.
final
- backgroundColor → Color?
-
The background color of the button.
final
- borderColor → Color?
-
The color of the button's border.
final
- borderRadius → double
-
The radius of the button's border.
final
- content → String
-
The text content of the button.
final
- contentColor → Color?
-
The color of the button's content.
final
- disabledColor → Color?
-
The color of the button when it is disabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCompact → bool
-
Whether the button should be compact or not.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsets
-
The margin around the button.
final
- maximumSize → Size
-
The maximum size of the button.
final
- minimumSize → Size
-
The minimum size of the button.
final
- onPressedF → dynamic Function()?
-
The function to call when the button is pressed.
final
- overlayColor → Color?
-
The color of the button's overlay.
final
- padding → EdgeInsets
-
The padding inside the button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
The style of the button's text content.
final
- widgetContent → Widget?
-
An optional widget to display instead of the text content.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited