FxTextField class
FxTextField is customizable text field widget with a default friendly style.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FxTextField
Constructors
- FxTextField({Key? key, required TextEditingController? inputController, Color? cursorColor, double? maxHeight, double? maxWidth, bool autoUnfocus = false, int? maxLines = 1, double shadowBlurRadius = 10.0, Offset shadowOffset = const Offset(0, 5), String? placeHolder, FocusNode? focusNode, TextInputType? inputType, dynamic onChanged(String)?, dynamic onSubmitted(String)?, EdgeInsets? inputPadding, TextStyle? textStyle, String? label, TextStyle? errorStyle, bool? enableInput, String? errorText, InputBorder? inputBorder, bool? autoFocus, bool? obscureText, Widget? suffixIcon, Widget? prefixIcon, EdgeInsetsGeometry margin = const EdgeInsets.symmetric(vertical: 5.0), Color backgroundColor = FxColors.lightGray})
-
const
Properties
- autoFocus → bool?
-
Whether the text field should autofocus or not.
final
- autoUnfocus → bool
-
Whether the text field should auto-unfocus or not.
final
- backgroundColor → Color
-
The background color of the text field.
final
- cursorColor → Color?
-
The color of the cursor.
final
- defaultTextStyle → TextStyle
-
final
- enableInput → bool?
-
Whether the text field is enabled for input or not.
final
- errorStyle → TextStyle?
-
The error text style for the text field.
final
- errorText → String?
-
The error text to display for the text field.
final
- focusNode → FocusNode?
-
The focus node for the text field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputBorder → InputBorder?
-
The border for the text field.
final
- inputController → TextEditingController?
-
The text controller for the text field.
final
- inputPadding → EdgeInsets?
-
The padding inside the text field.
final
- inputType → TextInputType?
-
The type of keyboard to display for the text field.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
The label of the text field.
final
- margin → EdgeInsetsGeometry
-
The margin around the text field.
final
- maxHeight → double?
-
The maximum height for the text field.
final
- maxLines → int?
-
The maximum number of lines for the text field.
final
- maxWidth → double?
-
The maximum width for the text field.
final
- obscureText → bool?
-
Whether the text field's text should be obscured or not.
final
- onChanged → dynamic Function(String)?
-
The callback function for when the text field's text changes.
final
- onSubmitted → dynamic Function(String)?
-
The callback function for when the text field's text is submitted.
final
- placeHolder → String?
-
The placeholder text to display for the text field.
final
- prefixIcon → Widget?
-
The prefix icon to display for the text field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowBlurRadius → double
-
The blur radius of the text field's shadow.
final
- shadowOffset → Offset
-
The offset of the text field's shadow.
final
- suffixIcon → Widget?
-
The suffix icon to display for the text field.
final
- textStyle → TextStyle?
-
The text style for the text field.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited